Index: media/base/media_observer.h |
diff --git a/media/base/media_observer.h b/media/base/media_observer.h |
index f5b1fb6906333ccf234031a23700a5629019f0d7..6fa7fa042d6283f96cf283e7355686217aeb5c82 100644 |
--- a/media/base/media_observer.h |
+++ b/media/base/media_observer.h |
@@ -16,9 +16,10 @@ class MEDIA_EXPORT MediaObserverClient { |
virtual ~MediaObserverClient() {} |
// Requests to restart the media pipeline and create a new renderer as soon as |
- // possible. |disable_pipeline_auto_suspend| indicates whether to disable |
- // any optimizations that might suspend the media pipeline. |
- virtual void SwitchRenderer(bool disable_pipeline_auto_suspend) = 0; |
+ // possible. |is_rendered_remotely| indicates whether to render the media |
+ // remotely. When it is true, all the optimizations that might suspend the |
+ // media pipeline are disabled. |
+ virtual void SwitchRenderer(bool is_rendered_remotely) = 0; |
// Requests to activate monitoring changes on viewport intersection. |
virtual void ActivateViewportIntersectionMonitoring(bool activate) = 0; |